@@ -30,7 +30,8 @@ kConfigPaths = {
     'grid': 'config/grid'
 }
 
-kiDDSBasePath = '/HPOiDDS'
+kDockerBasePath = '/workDir'
+kiDDSBasePath = kDockerBasePath
 kGridSiteWorkDir = '/srv/workDir/'
 
 #####################################################
@@ -74,6 +75,10 @@ kMetricMode = ['min', 'max']
 
 kDefaultOutDS = 'user.${{RUCIO_ACCOUNT}}.hpogrid.{HPO_PROJECT_NAME}.out.$(date +%Y%m%d%H%M%S)'
 
+kHPOGridMetadataFormat = ['task_time_s', 'start_timestamp', 'project_name', 
+                          'result', 'hyperparameters', 'metric', 'start_datetime', 
+                          'best_config', 'end_datetime', 'mode']
+
 kProjConfigFormat = {
     'project_name': {
         'required': True,
@@ -280,7 +285,4 @@ kDefaultModelParam = json.dumps(kConfigFormat['model']['param']['default'])
 
 kHPOGridMetadataFormat = ['project_name', 'metric', 'mode', 'task_time_s', 'result', 'hyperparameters', 'best_config', 'start_datetime', 'end_datetime', 'start_timestamp']
 
-kGridSiteMetadataFileName = 'userJobMetadata.json' #jobReport.json
-
-kWorkDir = './'
-kDataDir = './'
\ No newline at end of file
+kGridSiteMetadataFileName = 'userJobMetadata.json' #jobReport.json
\ No newline at end of file
