@@ -24,19 +24,22 @@ def transpose_config(config):
     generator_options = {}
     generator_options['n_point'] = '%NUM_POINTS'
     generator_options['max_point'] = '%MAX_POINTS'
-    generator_options['infile'] = os.path.join(kiDDSBasePath, '%IN')
-    generator_options['outfile'] = os.path.join(kiDDSBasePath, '%OUT')
-    generator_options['library'] = library
+    generator_options['infile'] = os.path.join("/HPOiDDS", '%IN')
+    generator_options['outfile'] = os.path.join("/HPOiDDS", '%OUT')
+    generator_options['lib'] = library
     if (library == 'nevergrad') and method:
         generator_options['method'] = method
     generator_cmd = 'hpogrid generate {}'.format(stylus.join_options(generator_options))
 
     # format idds configuration
     idds_config = {}
+    #idds_config['steeringExec'] = ("run --rm -v \"$(pwd)\":{idds_base_path} {container} " +\
+    #"/bin/bash -c \"{cmd}\" ").format(idds_base_path=kiDDSBasePath, container=kDefaultiDDSContainer, cmd=generator_cmd)
     idds_config['steeringExec'] = ("run --rm -v \"$(pwd)\":{idds_base_path} {container} " +\
-    "/bin/bash -c \"{cmd}\" ").format(idds_base_path=kiDDSBasePath, container=kDefaultiDDSContainer, cmd=generator_cmd)
-    idds_config['evaluationExec'] = "\"pip install --upgrade hpogrid && " + \
-                                    "hpogrid run {project_name} --mode idds\"".format(project_name=project_name)
+    "/bin/bash -c \"{cmd}\" ").format(idds_base_path="/HPOiDDS", container="gitlab-registry.cern.ch/zhangruihpc/steeringcontainer:0.0.2", cmd=generator_cmd)
+
+    idds_config['evaluationExec'] = "pip install --upgrade hpogrid && " + \
+                                    "hpogrid run {project_name} --mode idds".format(project_name=project_name)
     idds_config['evaluationContainer'] = evaluation_container
     idds_config['evaluationInput'] = kiDDSHPinput
     idds_config['evaluationOutput'] = kiDDSHPoutput
@@ -95,7 +98,9 @@ def check_log(workload_id:int, request_id=None,
     from idds.common.utils import get_rest_host
     host = get_rest_host()
     client = Client(host=host)
-    print('INFO: Fetching iDDS log files for tht task: {}'.format(workload_id))
+#    from pdb import set_trace
+#    set_trace()
+    print('INFO: Fetching iDDS log files for the task: {}'.format(workload_id))
     filename = client.download_logs(workload_id=workload_id, request_id=request_id, dest_dir='/tmp')
     print('INFO: iDDS log files can be found at:')
     print(filename)
