@@ -26,16 +26,24 @@ def join_options(options):
     return ' '.join(["--{} {}".format(key,value) for (key,value) in options.items()])
 
 def create_table(data, columns=None, indexed=True, transpose=False,
-    tableformat=kDefaultTableStyle, stralign=kDefaultStrAlign,
-    wrap_nested_dict=False):
+    tableformat=kDefaultTableStyle, stralign=kDefaultStrAlign):
+    df = pd.DataFrame(data, columns=columns)
+    if transpose:
+        df = df.transpose()
+    table = tabulate(df, showindex=indexed, headers=df.columns, 
+        tablefmt=tableformat,
+        stralign=stralign)
+    return table
+
+def create_formated_dict(data, columns=None, indexed=True, transpose=False,
+    tableformat=kDefaultTableStyle, stralign=kDefaultStrAlign):
     _data = copy.deepcopy(data)
     if isinstance(_data, dict):
         for key in _data:
             if isinstance(_data[key], dict):
                 _data[key] = yaml.dump(_data[key], allow_unicode=True,
                                        default_flow_style=False, sort_keys=False)
-    _data = _data.items() if isinstance(data, dict) else _data
-    df = pd.DataFrame(_data, columns=columns)
+    df = pd.DataFrame(_data.items(), columns=columns)
     if transpose:
         df = df.transpose()
     table = tabulate(df, showindex=indexed, headers=df.columns, 
